src/pyams_default_theme/features/search/portlet/interfaces.py
changeset 461 0aebe2d107ac
parent 436 c72e9d8bfcda
child 472 ebef14b037b3
--- a/src/pyams_default_theme/features/search/portlet/interfaces.py	Tue Sep 17 12:00:26 2019 +0200
+++ b/src/pyams_default_theme/features/search/portlet/interfaces.py	Wed Sep 25 10:05:57 2019 +0200
@@ -9,6 +9,8 @@
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE.
 #
+from pyams_i18n.schema import I18nTextLineField
+
 
 __docformat__ = 'restructuredtext'
 
@@ -39,8 +41,8 @@
     header = Attribute("Search result header")
 
 
-class ISearchResultsPortletDefaultRendererSettings(Interface):
-    """Search results portlet default renderer settings interface"""
+class ISearchResultsPortletRendererBaseSettings(Interface):
+    """Search results portlet renderer base settings interface"""
 
     display_results_count = Bool(title=_("Display results count?"),
                                  description=_("If 'no', results count will not be displayed"),
@@ -56,3 +58,18 @@
                             description=_("If 'no', results will not be paginated"),
                             required=True,
                             default=True)
+
+
+class ISearchResultsPortletDefaultRendererSettings(ISearchResultsPortletRendererBaseSettings):
+    """Search results portlet default renderer settings interface"""
+
+
+class ISearchResultsPortletPanelsRendererSettings(ISearchResultsPortletRendererBaseSettings):
+    """Search results portlet panels renderer settings interface"""
+
+    button_title = I18nTextLineField(title=_("Button's title"),
+                                     description=_("Navigation button's title is normally defined "
+                                                   "based on target's content type; you can "
+                                                   "override this label by giving a custom title "
+                                                   "here"),
+                                     required=False)